@@ -469,6 +469,10 @@ class Machine(MachineBase):
             f" -config {certs_dir}/selfsigned-ip.cnf"
         )
 
+        self.run(f"sudo cp /var/lib/tor/main/hostname {self.run_dir}/onion")
+        self.run(f"sudo chown gaea:gaea {self.run_dir}/onion")
+        self.run(f"touch {self.run_dir}/domains")
+
         self.user = "root"
 
         # git server
@@ -481,10 +485,6 @@ class Machine(MachineBase):
         self.run("systemctl daemon-reload")
         self.run("service fcgiwrap restart")
 
-        self.run(f"cp /var/lib/tor/main/hostname {self.run_dir}/onion")
-        self.run(f"chown gaea:gaea {self.run_dir}/onion")
-        self.run(f"touch {self.run_dir}/domains")
-
         self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
         self.run("service nginx restart")
 
@@ -507,7 +507,8 @@ class Machine(MachineBase):
         if webcfg:
             self.run(
                 f"cat > {self.run_dir}/webcfg.ini",
-                stdin="\n".join(f'{k.upper()} = "{v}"' for k, v in webcfg.items()),
+                stdin="\n".join(f'{k.upper()} = "{v}"' for k, v in webcfg.items())
+                + "\n",
             )
 
         self.run(f"{self.runinenv} app pip install {package}")
