@@ -76,7 +76,8 @@ class DigitalOcean(Host):
         self,
         name,
         region="sfo3",
-        size="s-1vcpu-1gb-intel",
+        size="s-1vcpu-512mb-10gb",  # $4/mo
+        # size="s-1vcpu-1gb-intel",  # $7/mo
         image="debian-11-x64",
         ssh_keys=None,
     ):
